@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.010';
+our $VERSION = '0.011';
 
 use Moose;
 
@@ -88,12 +88,15 @@ sub munge_files {
     # because it calls _build_version which is going to fail the build.
     # Besides that, VersionFromMainModule is run during the "munge files"
     # phase and before that we can't even know the new version of the bundle.
-    #
-    ## no critic (ValuesAndExpressions::RequireConstantVersion)
-    $VERSION = $self->zilla->version;
 
-    # re-write all generated files
-    $self->_write_files();
+    {
+        ## no critic (ValuesAndExpressions::RequireConstantVersion)
+        ## no critic (Variables::ProhibitLocalVars)
+        local $VERSION = $self->zilla->version;
+
+        # re-write all generated files
+        $self->_write_files();
+    }
 
     return;
 }
@@ -125,9 +128,35 @@ sub _write_files {
     return;
 }
 
-# Files to generate
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Dist::Zilla::Plugin::Author::SKIRMESS::RepositoryBase - Automatically create and update files
+
+=head1 VERSION
+
+Version 0.010
+
+=head1 SYNOPSIS
+
+This plugin is part of the
+L<Dist::Zilla::PluginBundle::Author::SKIRMESS|Dist::Zilla::PluginBundle::Author::SKIRMESS>
+bundle and should not be used outside of that.
+
+=head1 DESCRIPTION
+
+This plugin creates a collection of files that are shared between all my
+CPAN distributions which makes it easy to keep them all up to date.
+
+The following files are created in the repository and in the distribution:
+
+=cut
 
 {
+    # Files to generate
     my %file;
 
     sub files {
@@ -160,7 +189,14 @@ sub _write_files {
         );
     }
 
-    #.perlcriticrc
+=head2 .perlcriticrc
+
+The configuration for L<Perl::Critic|Perl::Critic>. This file is created from
+a default contained in this plugin and from distribution specific settings in
+F<perlcriticrc.local>.
+
+=cut
+
     $file{q{.perlcriticrc}} = sub {
         my ($self) = @_;
 
@@ -389,7 +425,12 @@ PERLCRITICRC_TEMPLATE
         return $content;
     };
 
-    # .perltidyrc
+=head2 .perltidyrc
+
+The configuration file for B<perltidy>.
+
+=cut
+
     $file{q{.perltidyrc}} = <<'PERLTIDYRC';
 # Automatically generated file
 # {{ ref $plugin }} {{ $plugin->VERSION() }}
@@ -400,7 +441,13 @@ PERLCRITICRC_TEMPLATE
 --output-line-ending=unix
 PERLTIDYRC
 
-    # .travis.yml
+=head2 .travis.yml
+
+The configuration file for TravisCI. All known supported Perl versions are
+enabled unless disabled with B<travis_ci_ignore_perl>.
+
+=cut
+
     $file{q{.travis.yml}} = sub {
         my ($self) = @_;
 
@@ -451,14 +498,24 @@ use warnings;
 
 _TEST_HEADER
 
-    # xt/author/clean-namespaces.t
+=head2 xt/author/clean-namespaces.t
+
+L<Test::CleanNamespaces|Test::CleanNamespaces> author test.
+
+=cut
+
     $file{q{xt/author/clean-namespaces.t}} = $test_header . <<'XT_AUTHOR_CLEAN_NAMESPACES_T';
 use Test::CleanNamespaces;
 
 all_namespaces_clean();
 XT_AUTHOR_CLEAN_NAMESPACES_T
 
-    # xt/author/critic.t
+=head2 xt/author/critic.t
+
+L<Test::Perl::Critic|Test::Perl::Critic> author test.
+
+=cut
+
     $file{q{xt/author/critic.t}} = $test_header . <<'XT_AUTHOR_CRITIC_T';
 use File::Spec;
 
@@ -481,28 +538,48 @@ if ( @files == 0 ) {
 all_critic_ok(@files);
 XT_AUTHOR_CRITIC_T
 
-    # xt/author/minimum_version.t
+=head2 xt/author/minimum_version.t
+
+L<Test::MinimumVersion|Test::MinimumVersion> author test.
+
+=cut
+
     $file{q{xt/author/minimum_version.t}} = $test_header . <<'XT_AUTHOR_MINIMUM_VERSION_T';
 use Test::MinimumVersion 0.008;
 
 all_minimum_version_from_metayml_ok();
 XT_AUTHOR_MINIMUM_VERSION_T
 
-    # xt/author/mojibake.t
+=head2 xt/author/mojibake.t
+
+L<Test::Mojibake|Test::Mojibake> author test.
+
+=cut
+
     $file{q{xt/author/mojibake.t}} = $test_header . <<'XT_AUTHOR_MOJIBAKE_T';
 use Test::Mojibake;
 
 all_files_encoding_ok( grep { -d } qw( bin lib t xt ) );
 XT_AUTHOR_MOJIBAKE_T
 
-    # xt/author/no-tabs.t
+=head2 xt/author/no-tabs.t
+
+L<Test::NoTabs|Test::NoTabs> author test.
+
+=cut
+
     $file{q{xt/author/no-tabs.t}} = $test_header . <<'XT_AUTHOR_NO_TABS_T';
 use Test::NoTabs;
 
 all_perl_files_ok( grep { -d } qw( bin lib t xt ) );
 XT_AUTHOR_NO_TABS_T
 
-    # xt/author/pod-no404s.t
+=head2 xt/author/pod-no404s.t
+
+L<Test::Pod::No404s|Test::Pod::No404s> author test.
+
+=cut
+
     $file{q{xt/author/pod-no404s.t}} = $test_header . <<'XT_AUTHOR_POD_NO404S_T';
 if ( exists $ENV{AUTOMATED_TESTING} ) {
     print "1..0 # SKIP these tests during AUTOMATED_TESTING\n";
@@ -514,7 +591,12 @@ use Test::Pod::No404s;
 all_pod_files_ok();
 XT_AUTHOR_POD_NO404S_T
 
-    # xt/author/pod-spell.t
+=head2 xt/author/pod-spell.t
+
+L<Test::Spelling|Test::Spelling> author test. B<stopwords> are added as stopwords.
+
+=cut
+
     $file{q{xt/author/pod-spell.t}} = sub {
         my ($self) = @_;
 
@@ -536,14 +618,24 @@ XT_AUTHOR_POD_SPELL_T
         return $content;
     };
 
-    # xt/author/pod-syntax.t
+=head2 xt/author/pod-syntax.t
+
+L<Test::Pod|Test::Pod> author test.
+
+=cut
+
     $file{q{xt/author/pod-syntax.t}} = $test_header . <<'XT_AUTHOR_POD_SYNTAX_T';
 use Test::Pod 1.26;
 
 all_pod_files_ok( grep { -d } qw( bin lib t xt) );
 XT_AUTHOR_POD_SYNTAX_T
 
-    # xt/author/portability.t
+=head2 xt/author/portability.t
+
+L<Test::Portability::Files|Test::Portability::Files> author test.
+
+=cut
+
     $file{q{xt/author/portability.t}} = $test_header . <<'XT_AUTHOR_PORTABILITY_T';
 BEGIN {
     if ( !-f 'MANIFEST' ) {
@@ -558,7 +650,12 @@ options( test_one_dot => 0 );
 run_tests();
 XT_AUTHOR_PORTABILITY_T
 
-    # xt/author/test-version.t
+=head2 xt/author/test-version.t
+
+L<Test::Version|Test::Version> author test.
+
+=cut
+
     $file{q{xt/author/test-version.t}} = $test_header . <<'XT_AUTHOR_TEST_VERSION_T';
 use Test::More 0.88;
 use Test::Version 0.04 qw( version_all_ok ), {
@@ -572,21 +669,36 @@ version_all_ok;
 done_testing();
 XT_AUTHOR_TEST_VERSION_T
 
-    # xt/release/changes.t
+=head2 xt/release/changes.t
+
+L<Test::CPAN::Changes|Test::CPAN::Changes> release test.
+
+=cut
+
     $file{q{xt/release/changes.t}} = $test_header . <<'XT_RELEASE_CHANGES_T';
 use Test::CPAN::Changes;
 
 changes_ok();
 XT_RELEASE_CHANGES_T
 
-    # xt/release/eol.t
+=head2 xt/release/eol.t
+
+L<Test::EOL|Test::EOL> release test.
+
+=cut
+
     $file{q{xt/release/eol.t}} = $test_header . <<'XT_RELEASE_EOL_T';
 use Test::EOL;
 
 all_perl_files_ok( { trailing_whitespace => 1 }, grep { -d } qw( bin lib t xt) );
 XT_RELEASE_EOL_T
 
-    # xt/release/kwalitee.t
+=head2 xt/release/kwalitee.t
+
+L<Test::Kwalitee|Test::Kwalitee> release test.
+
+=cut
+
     $file{q{xt/release/kwalitee.t}} = $test_header . <<'XT_RELEASE_KWALITEE_T';
 use Test::More 0.88;
 use Test::Kwalitee 'kwalitee_ok';
@@ -597,21 +709,36 @@ kwalitee_ok(qw{-has_license_in_source_file -has_abstract_in_pod});
 done_testing();
 XT_RELEASE_KWALITEE_T
 
-    # xt/release/manifest.t
+=head2 xt/release/manifest.t
+
+L<Test::DistManifest|Test::DistManifest> release test.
+
+=cut
+
     $file{q{xt/release/manifest.t}} = $test_header . <<'XT_RELEASE_MANIFEST_T';
 use Test::DistManifest 1.003;
 
 manifest_ok();
 XT_RELEASE_MANIFEST_T
 
-    # xt/release/meta-json.t
+=head2 xt/release/meta-json.t
+
+L<Test::CPAN::Meta::JSON|Test::CPAN::Meta::JSON> release test.
+
+=cut
+
     $file{q{xt/release/meta-json.t}} = $test_header . <<'XT_RELEASE_META_JSON_T';
 use Test::CPAN::Meta::JSON;
 
 meta_json_ok();
 XT_RELEASE_META_JSON_T
 
-    # xt/release/meta-yaml.t
+=head2 xt/release/meta-yaml.t
+
+L<Test::CPAN::Meta|Test::CPAN::Meta> release test.
+
+=cut
+
     $file{q{xt/release/meta-yaml.t}} = $test_header . <<'XT_RELEASE_META_YAML_T';
 use Test::CPAN::Meta 0.12;
 
@@ -623,4 +750,55 @@ __PACKAGE__->meta->make_immutable;
 
 1;
 
+__END__
+
+=head1 USAGE
+
+The following configuration options are supported:
+
+=head2 stopwords
+
+Defines stopwords for the spell checker.
+
+=head2 travis_ci_ignore_perl
+
+By default, the generated F<.travis.yml> file runs on all Perl version known
+to exist on TravisCI. Use the B<travis_ci_ignore_perl> option to define Perl
+versions to not check.
+
+=head1 SUPPORT
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests through the issue tracker
+at L<https://github.com/skirmess/Dist-Zilla-PluginBundle-Author-SKIRMESS/issues>.
+You will be notified automatically of any progress on your issue.
+
+=head2 Source Code
+
+This is open source software. The code repository is available for
+public review and contribution under the terms of the license.
+
+L<https://github.com/skirmess/Dist-Zilla-PluginBundle-Author-SKIRMESS>
+
+  git clone https://github.com/skirmess/Dist-Zilla-PluginBundle-Author-SKIRMESS.git
+
+=head1 AUTHOR
+
+Sven Kirmess <sven.kirmess@kzone.ch>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2017 by Sven Kirmess.
+
+This is free software, licensed under:
+
+  The (two-clause) FreeBSD License
+
+=head1 SEE ALSO
+
+L<Dist::Zilla::PluginBundle::Author::SKIRMESS|Dist::Zilla::PluginBundle::Author::SKIRMESS>
+
+=cut
+
 # vim: ts=4 sts=4 sw=4 et: syntax=perl
